# Google Bard
- [Google Bard](https://bard.google.com)
- [AGiXT](https://github.com/Josh-XT/AGiXT)

## Disclaimer

We are not responsible if Google bans your account for doing this. This may not be consistent with their rules to use their services in this way. This was developed for experimental purposes and we assume no responsibility for how you use it.

## Quick Start Guide

### Get your Google Bard Token

1. Open Google Chrome and navigate to https://bard.google.com/
2. Press F12 for console
3. Go to Application → Cookies → `__Secure-1PSID`. Copy the value of that cookie. That is your bard token.

### Update your agent settings
1. Update `BARD_TOKEN` with the value of `__Secure-1PSID`.
2. `AI_MODEL` is `bard` for Google Bard.